!**************************************************************************************************
! Calculation of photosynthesis parameters (for each PFT)
!**************************************************************************************************
SUBROUTINE photosynthesis_condition (tmp_air)

!_____________ Set variables
!Namespace
   USE data_structure
   USE vegi_status_current1
   USE vegi_status_current2
   USE grid_status_current2
   USE grid_status_record
   implicit none
   
!Define Auguments
   real,intent(IN)::tmp_air
   
!Define local variables
   real   p_ave    !average photosynthetic rate
   real   gs_ave   !daily mean stomatal conductance (mol H2O m-2 s-1)
   real   co2cell  !monthly intercellular CO2 concentration (ppmv)
   real   topt     !adjusted optimum temperature (deg C)
   real   ce_tmp   !temperature effect on photosynthesis
   real   ce_co2   !stomatal effect on photosynthesis via intercellular CO2 concentration
   real,dimension(PFT_no)::ce_water !non-stomatal effect on photosynthesis
   
   real                  :: a1, a2, x, y, z
   integer               :: loop, p, i, no, gn
   real,dimension(Max_no):: par_ave       !average PAR intensity receiving for each tree
   real,dimension(2)     :: par_ave_grass !average PAR intensity receiving for grass PFTs
   
!_____________ The Condition that plants can survive by Koppen (1936) (optional)
   a1 = sum(prec_RunningRecord(1:365))            !annual precipitation (mm/year)
   a2 = sum(tmp_air_RunningRecord(1:365)) / 365.0 !annual mean temperature (Celcius)
   if ( a1 < max(100.0, 10.0*a2) ) then
      lue          (:) = 0.0
      co2cmp       (:) = 0.0
      psat         (:) = 0.0
      lue_grass    (:) = 0.0
      co2cmp_grass (:) = 0.0
      psat_grass   (:) = 0.0
      return
   endif
   
!_____________ Preparation of PFT specific varables
   Do p=1, PFT_no
      !eK: adjusted light-attenuation-coefficient
      eK(p) = EK0(p) / min(1.0, max(0.3, sin(0.86 * sl_hgt * DtoR)))
      
      !ce_water: limitation on photosynthesis via soil water
      ce_water(p) = min( 1.0 , max(0.001, stat_water(p)) )
      ce_water(p) = ce_water(p) ** 0.5   
      
   End do
   
!_____________ Preparation relative light intensity
!par_ave: relative PAR intensity for each tree
   par_ave(:) = 0.0
   
!x: fraction of direct PAR
   x = par_direct / max(0.0001, par_direct+par_diffuse)
   x = max(x, 0.0)
   x = min(x, 1.0)
   
   DO no=1, Max_no
      if ( .not. tree_exist(no)     ) cycle
      if ( .not. phenology(pft(no)) ) cycle
      if ( la(no) <=0.0             ) cycle
      
      do i = height(no), bole(no)+1, -1
         par_ave(no) = par_ave(no)  + x * par_direct_rel(no,i) + (1.0-x) * par_diffuse_rel(i)
      end do
      par_ave(no) = (0.5*par) * par_ave(no) / (height(no)-bole(no))
      
   END DO
   
!for each grass PFT (temporal way of calculation)
   par_ave_grass(1) = 0.5 * par_grass !C3 grass
   par_ave_grass(2) = 0.5 * par_grass !C4 grass
   
!_____________ Compute photosynthesis condition for each tree
Do no = 1, Max_no
   
   if ( .not. tree_exist(no)     ) cycle
   if ( .not. phenology(pft(no)) ) cycle
   if ( la(no) <=0.0             ) cycle
   
   !initialize
   p        = pft(no)
   psat(no) = Pmax(p) * 0.7 !initial psat, initial light_saturated photosynthesis rate
   co2cell  = co2atm  * 0.7 !initial intercellular CO2 concentration
   
   !loop for parameter convergence
do loop = 0, 5
    !------------------------------------------------------------!
    !lue: light use efficiency (mol CO2 mon photon-1)
    !------------------------------------------------------------!
    a1      = (52.0-tmp_air) / (3.5+0.75*(52.0-tmp_air)) !temperature dependence factor
    a2      = co2cell / (90.0+0.6*co2cell)               !CO2 dependence factor
    lue(no) = Lue0(p) * a1 * a2
    
    !------------------------------------------------------------!
    ! ce_tmp: temperature effect on photosynthesis
    !------------------------------------------------------------!
    ! optimum photosynthesis temperature
    if ( (tmp_air<=Tmin(p)) .or. (tmp_air>=Tmax(p)) ) then
       ce_tmp=0.0
    else
       topt = Topt0(p) + 0.01 * co2cell
       ce_tmp = (tmp_air-Tmax(p)) * (tmp_air-Tmin(p)) / &
                ( (tmp_air-Tmax(p))*(tmp_air-Tmin(p)) - (tmp_air-topt)**2 )
       ce_tmp = min(1.0, max(0.0, ce_tmp ))
    endif
    
    !------------------------------------------------------------!
    ! ce_co2: stomatal limitation on photosynthesis via co2cell
    !------------------------------------------------------------!
    ! compcd: CO2 compensation point
    a1         = 1.00+0.0451*(tmp_air-20.0)+0.000347*((tmp_air-20.0)**2)
    co2cmp(no) = CO2cmp0(p) * max(0.0, a1) 
    ce_co2     = 0.30 + 0.70 * (co2cell-co2cmp(no))/(KM(p)+co2cell)
    ce_co2     = min(1.0, max(0.0, ce_co2))
    
    !------------------------------------------------------------!
    !psat: light-saturated photosynthesis rate (micro mol CO2 m-2 s-1)
    !------------------------------------------------------------!
    psat(no)= Pmax(p) * ce_tmp * ce_co2 * ce_water(p)
    
    !------------------------------------------------------------!
    !ptop: canopy-top photosynthetic rate (micro mol CO2 m-2 s-1)
    !------------------------------------------------------------!
    a1 = psat(no) * lue(no) * par_ave(no)
    a2 = psat(no) + lue(no) * par_ave(no)
    
    if (a2 > 0.0) then; p_ave = a1/a2
    else              ; p_ave = 0.0  
    endif                           
    
    !------------------------------------------------------------!
    !gs_ave: daily mean stomatal conductance (mol H2O m-2 s-1)
    !        Leuning (1995)
    !------------------------------------------------------------!
    gs_ave = GS_b1(p) + ( GS_b2(p)*p_ave ) / ( (co2atm-co2cmp(no))*(1.0+vpd/GS_b3(p)) )
    
    !------------------------------------------------------------!
    !co2cell: intercellular CO2 concentration (ppmv)
    !------------------------------------------------------------!
    a1      = gs_ave / 1.56    !1.56: conversion from H2O to CO2 conductance
    co2cell = co2atm - p_ave / a1 !Leuning (1995)
    co2cell = max(0.0, min(co2atm, co2cell))
    
end do

END DO


!_____________ Comupte photosynthesis condition for each grass PFT
Do gn = 1, 2
   
   if (gn == 1) then
      p=C3g_no
   else
      p=C4g_no
   endif
   
   psat_grass(gn) = Pmax(p) * 0.7 !initial psat, initial light_saturated photosynthesis rate
   co2cell        = co2atm  * 0.7 !initial intercellular CO2 concentration
   
!loop for parameter convergence
do loop = 0, 5
    !------------------------------------------------------------!
    !lue: light use efficiency (mol CO2 mon photon-1)
    !------------------------------------------------------------!
    if (gn==1) then
       a1 = (52.0-tmp_air) / (3.5+0.75*(52.0-tmp_air)) !temperature dependence factor
       a2 = co2cell / (90.0+0.6*co2cell)               !CO2 dependence factor
    else
       a1 = 1.0                                        !temperature insensitive
       a2 = 1.0                                        !CO2 insensitive 
    endif
    lue_grass(gn) = Lue0(p) * a1 * a2
    
    !------------------------------------------------------------!
    ! ce_tmp: temperature effect on photosynthesis
    !------------------------------------------------------------!
    ! optimum photosynthesis temperature
    if (gn==1) then
       topt = Topt0(p) + 0.01 * co2cell
    else
       topt = Topt0(p)
    end if
    
    if (gn==1) then
       topt = sum( tmp_ave_C3growth_RunningRecord(1:20) ) / 20.0
       topt = max(10.0, topt)
       topt = min(30.0, topt)
    else
       topt = sum( tmp_ave_C4growth_RunningRecord(1:20) ) / 20.0
       topt = max(20.0, topt)
       topt = min(40.0, topt)
    endif
    
    if ( (tmp_air<=Tmin(p)) .or. (tmp_air>=Tmax(p)) ) then
       ce_tmp = 0.0
    else
       ce_tmp = (tmp_air-Tmax(p)) * (tmp_air-Tmin(p)) / &
                ( (tmp_air-Tmax(p)) * (tmp_air-Tmin(p)) - (tmp_air-topt)**2 )
       ce_tmp = min(1.0, max(0.0, ce_tmp ))
    endif
    
    !------------------------------------------------------------!
    ! ce_co2: stomatal limitation on photosynthesis via co2cell
    !------------------------------------------------------------!
    ! compcd: CO2 compensation point
    if(gn==1) then
       a1               = 1.00+0.0451*(tmp_air-20.0)+0.000347*((tmp_air-20.0)**2)
       co2cmp_grass(gn) = CO2cmp0(p) * max(0.0, a1) 
       ce_co2           = 0.30 + 0.70 * (co2cell-co2cmp_grass(gn))/(KM(p)+co2cell)
    else
       co2cmp_grass(gn) = CO2cmp0(p)
       ce_co2           = 0.50 + 0.50 * (co2cell-co2cmp_grass(gn))/(KM(p)+co2cell)
    endif
    ce_co2 = min(1.0, max(0.0, ce_co2))
    
    !------------------------------------------------------------!
    !psat: light-saturated photosynthesis rate (micro mol CO2 m-2 s-1)
    !------------------------------------------------------------!
    psat_grass(gn)= Pmax(p) * ce_tmp * ce_co2 * ce_water(p)
    
    !------------------------------------------------------------!
    !ptop: canopy-top photosynthetic rate (micro mol CO2 m-2 s-1)
    !------------------------------------------------------------!
    a1 = psat_grass(gn) * lue_grass(gn) * par_ave_grass(gn)
    a2 = psat_grass(gn) + lue_grass(gn) * par_ave_grass(gn)
    
    if (a2 > 0.0) then; p_ave = a1/a2
    else              ; p_ave = 0.0  
    endif                           
    
    !------------------------------------------------------------!
    !gs_ave: stomatal conductance on top of the leaf layer (mol H2O m-2 s-1)
    !        Leuning (1995)
    !------------------------------------------------------------!
    gs_ave = GS_b1(p) + ( GS_b2(p)*p_ave ) / ( (co2atm-co2cmp_grass(gn))*(1.0+vpd/GS_b3(p)) )
    
    !------------------------------------------------------------!
    !co2cell: intercellular CO2 concentration (ppmv)
    !------------------------------------------------------------!
    a1      = gs_ave/1.56        !1.56: conversion from H2O to CO2 conductance
    co2cell = co2atm - p_ave / a1   !Leuning (1995)
    co2cell = max(0.0, min(co2atm, co2cell))
    
end do

END DO

END SUBROUTINE photosynthesis_condition



!**************************************************************************************************
! Daily GPP and Canopy_conductance
!**************************************************************************************************
SUBROUTINE photosynthesis ()

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   USE vegi_status_current2
   USE vegi_status_record
   USE grid_status_current1
   USE grid_status_current2
   USE grid_status_record
   implicit none
   
!Define local variables
   real    const0, const1, const2, const3, const4, const5
   real    gpp_ind
   real    a0, a1, a2, a3, a4 !for general usage
   integer i, no, p, gn       !for loop counter
   integer count              !counter
   
!Define Local parameter
   real Unit_converter
        Unit_converter = 3600.0 * 12.0 / 1000000.0 / C_in_drymass
   ! constant for unit conversion
   ! from (micro mol CO2 m-2 s-1) to (g dm m-2 hour-1)
   ! micro mol  -> mol       :* 10^-6
   ! mol        -> g(Carbon) :* 12
   ! secound^-1 -> hour^-1   :* 3600

!_____________ Woody PFTs
count = 0
DO no=1, Max_no
   
   !initialize gpp of a tree
   gpp_ind = 0.000
   p = pft(no)
   
   if ( .not. tree_exist(no) ) cycle
   if ( .not. phenology(p)   ) cycle
   if ( la(no)  <=0.0        ) cycle
   if ( psat(no) <= 0.0      ) cycle
   
   const0 = GS_b2(p) * psat(no) / max(0.01, co2atm-co2cmp(no)) / (1.0 + vpd/GS_b3(p))
   const4 = Unit_converter * dlen * psat(no)  !
   const5 = la(no) / (height(no)-bole(no))    !leaf area per crown layer (m2/step)
   do i = height(no), bole(no)+1, -1
      !Photosynthesis
      a1      = par_diffuse*par_diffuse_rel(i) + par_direct*par_direct_rel(no,i) !PAR income
      a2      = 1.0 - (1.0+a1*lue(no)/psat(no))**(-0.5)
      a4      = const4*const5*a2                             !GPP (g dm/layer/day)
      gpp_ind = gpp_ind + a4
      
      !Canopy conductance
      canopy_cond = canopy_cond + const5 * ( GS_b1(p) + const0 * a2 )
      
      !Production recorder for each foliage disk
      if (i-bole(no)<=10) stat_leaf_crownbottom(no, i-bole(no)) = & 
                          stat_leaf_crownbottom(no, i-bole(no)) + a4
      if (i==height(no) ) stat_leaf_crowntop(no)                = & 
                          stat_leaf_crowntop(no)                + a4
      if (i==bole(no)+1 ) stat_leaf_crownbottom_daily(no)       = & 
                          stat_leaf_crownbottom_daily(no)       + a4
   end do
   
   !Increase mass_available & c_uptake
   mass_available (no) = mass_available(no) + gpp_ind
   gpp(p)              = gpp(p)             + gpp_ind
   npp(p)              = npp(p)             + gpp_ind
   gpp_month_ind(no)   = gpp_month_ind(no)  + gpp_ind
   
   mort_regu1(no)      = mort_regu1(no)     + gpp_ind
   c_uptake            = c_uptake           + gpp_ind * C_in_drymass
   
   !Benefit of producing new leaf mass (g / g Leaf)
   stat_leaf(no) = gpp_ind / mass_leaf(no)
   
END DO

!_____________ Herbaceous PFTs
DO gn=1,2
   !set PFT number, p
                p = C4g_no
   if ( gn==1 ) p = C3g_no
   
   !obtain coverage area: a0
                                    a0 = 0.1 * Max_loc*Max_loc
   if ( gn==1 .and. type_grass==3 ) a0 = 0.9 * Max_loc*Max_loc
   if ( gn==2 .and. type_grass==4 ) a0 = 0.9 * Max_loc*Max_loc
   
   !obtain GPP per unit area
   if (psat_grass(gn)>0.0) then
     const0 = GS_b2(p) * psat_grass(gn) / max(0.01, co2atm-co2cmp_grass(gn)) / (1.0 + vpd/GS_b3(p))
     const1 = Unit_converter * 2.0 * dlen * psat_grass(gn) / eK(p)
     const2 = eK(p) * lue_grass(gn) / psat_grass(gn)
     
     !obtain daily gpp per unit area (g dm / m2 / day)
     a2     = 1.0 + sqrt( 1.0 + par_grass * const2 )
     a3     = 1.0 + sqrt( 1.0 + par_grass * const2 * exp(-1.0*eK(p)*lai_grass(gn)) )
     const3 = log(a2/a3)
     gpp(p) = const1 * const3
     
     !increase gmass_available (g dm / m2 / day)
     gmass_available(gn) = gmass_available(gn) + gpp(p)
     
     !carbon balance
     gpp(p)   = gpp(p) * a0
     npp(p)   = gpp(p)
     c_uptake = c_uptake + gpp(p) * C_in_drymass
     
     !canopy conductance
     canopy_cond = canopy_cond + a0*( GS_b1(p)*lai_grass(gn) + const0*(2.0/eK(p))*const3 )
   endif
END DO

!Adjust canopy conductance
canopy_cond = canopy_cond / Max_loc / Max_loc

END SUBROUTINE photosynthesis



!**************************************************************************************************
! Optimum Leaf Area Index: daily computation using running mean of PAR
!**************************************************************************************************
SUBROUTINE lai_optimum (tmp_air, tmp_soil)

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   USE vegi_status_current2
   USE vegi_status_record
   USE grid_status_current2
   implicit none
   
!Argments
   real   ,intent(IN)::tmp_air   !2m air temperature (Celcius)
   real   ,intent(IN)::tmp_soil  !soil temperature at 10 cm  depth (Celcius)
   
!Local variables
   real    qt                    !QT10 of maintenance respiration
   real    tmp_sensibility_air   !temperature sensibility multiplier for foliage and stem
   real    tmp_sensibility_soil  !temperature sensibility multiplier for root
   real    x, y, a0, a1, a2, a3  !for general usage
   integer gn, p                 !loop counter
   real    const1, const2        !temporal usage
   
!Prepare temperature sensibility
   qt                   = 2.0 * exp( -0.009 * (tmp_air - 15.0) )
   tmp_sensibility_air  = exp( (tmp_air  - 15.0) * log(qt) / 10.0 )
   qt                   = 2.0 * exp( -0.009 * (tmp_soil - 15.0) )
   tmp_sensibility_soil = exp( (tmp_soil - 15.0) * log(qt) / 10.0 )

!Each PFT procedures
lai_opt_grass(:) = 0.0
do gn = 1 , 2
   
              p=C3g_no
   if (gn==2) p=C4g_no
   
   if (dlen           <= 0.1   ) cycle
   if (psat_grass(gn) <= 0.001 ) cycle
   if (lue_grass(gn)  <= 0.001 ) cycle
   if (eK(p)          <= 0.001 ) cycle
   if (par_grass      <= 1.00  ) cycle
   
   !a0: maintenance respiration rate of leaf (gDM / gDM / day)
   a0 = RM(p) * PN_f(p) * tmp_sensibility_air
   
   !a1: turnover cost of leaf (g DM g DM-1 day-1)
   if ( counter-pheno_clo(p)>365 ) then
      !evergreen
      a1 = (TO_f(p)/365.0) * ( RG_f(p) - RG_f_suck(p) )
   else
       !summer or rain green
      x  = max( 1   , 365 - (pheno_clo(p)-pheno_cls(p)) ) !x: number of growth day
      y  = max( 0.0 , TO_f(p) - 365/x )                   !y: corrected turnover rate
      a1 = (y      /365.0) * ( RG_f(p) - RG_f_suck(p) )
   endif
   
   !a2: maintenance respiration rate of root per unit leaf-mass (g DM g DM-1 day-1)
   a2 = RM(p) * PN_r(p) * tmp_sensibility_soil / FR_ratio(p)
   
   !a3: turnover cost of root (g DM g DM-1 day-1)
   !a3 = 0.0
   a3 = (TO_r(p)/365.0) * RG_r(p) / FR_ratio(p)
   
   !const1: daily maintenance cost of leaf (gDM / m2)
   const1 = (a0+a1+a2+a3)/SLA(p)
   const1 = max(0.0, const1)
   
   !optimum leaf index
   const2 = 1.0 - const1 / ( 0.09093*dlen*psat_grass(gn) )
if (const2 .ne. 0.0) then
   const2 = 1.0 / (const2*const2) - 1.0
   const2 = (psat_grass(gn)/lue_grass(gn)) * const2
endif
   
   if ( const2>0.0 ) then
      lai_opt_grass(gn) = ( log(par_grass/const2) ) / eK(p)
      lai_opt_grass(gn) = max(0.0, lai_opt_grass(gn))
   else
      lai_opt_grass(gn) = 0.0
   endif
   
end do
   
END SUBROUTINE lai_optimum



!**************************************************************************************************
! Leaf phenology (daily computation)
!**************************************************************************************************
SUBROUTINE leaf_season (LAT, tmp_soil)

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   USE vegi_status_current2
   USE vegi_status_record
   USE grid_status_current1
   USE grid_status_record
   implicit none
   
!Local parameters
   real,parameter::Stockmass_min_tree  = 10.0 !minimum stock mass for dormance (g dm/individual)
   real,parameter::Stockmass_min_grass = 50.0 !minimum stock mass for dormance (g dm/m2)
   real,parameter::Shedding_duration   = 14   !day lengh required for full leaf drop
   real,parameter::Day_length_release  = 14   !day lengh required for full release of stocked energy for woody PFTs
   
!Arguments
   real   ,intent(IN)::LAT       !latitude  (degree)
   real   ,intent(IN)::tmp_soil  
   
!Local variables
   real    tmp_air_10d_ave !1- days running mean of air temperature (Celcius)
   real    mass_assm       !biomass assimirated (g DM/day/stand)
   real    mass_combust    !biomass combust     (g DM/day/stand)
   
   logical                    flag_season  !flag for seasonal cycle
   logical,dimension(PFT_no)::flag         !flag for phenology change
   
   integer i, j, p, no, gn !for loop counter
   integer k, l, m, n      !for general usage
   real    x, y            !for general usage
   real    a1, a2, a3      !for general usage
   
   real    pheno_gdd !GDD on 5 degree base (reset: 1 Jan for N-hemisphere, 1 July for S-hemisphere)
   
   integer pheno_ncd !Number of chilling day, defined as number of days on which 
                     !the daily mean air temperature is below 5 Cecius degree
                     !(reset: 1 Nov for N-hemisphere, 1 May for S-hemisphere)
   
   real    mass_total      !total biomass before procedure --for checker-- (g DM/stand)
   real    day_until_bare  !day until full dormance
   
   integer doy_now
   real,dimension(2)::area_cover !coverage area for each grass PFT (m2)
   
!_____________ Initialize local variables
   mass_combust = 0.000
   
   if (type_grass==3) then
      area_cover(1) = 0.9 * Max_loc * Max_loc !Area coveraged by C3 grass (m2)
      area_cover(2) = 0.1 * Max_loc * Max_loc !Area coveraged by C4 grass (m2)
   else
      area_cover(1) = 0.1 * Max_loc * Max_loc !Area coveraged by C3 grass (m2)
      area_cover(2) = 0.2 * Max_loc * Max_loc !Area coveraged by C4 grass (m2)
   endif
   
!_____________ for carbon leaking checker 0 
   mass_total = pool_litter + &                                                         !Litter
     sum(mass_leaf)+sum(mass_root)+sum(mass_available)+sum(mass_stock)+ &               !Trees
     area_cover(1) * (gmass_leaf(1)+gmass_root(1)+gmass_available(1)+gmass_stock(1))+ & !C3 g
     area_cover(2) * (gmass_leaf(2)+gmass_root(2)+gmass_available(2)+gmass_stock(2))    !C4 g
   
!_____________ Prepare related variables
pheno_gdd = 0.0
pheno_ncd = 1

do i= 1, 365 !from 364days before to today
   
   !day of year for current repeat
   doy_now = doy - 365 + i
   if (doy_now <= 0) doy_now = doy_now + 365
   
   !air temperature for current repeat
   x = tmp_air_RunningRecord (365-i+1)
   
   !pheno_gdd
   if ( (doy_now==1 .and. LAT>=0.0) .or. (doy_now==182 .and. LAT<0.0) ) then
        pheno_gdd = 0.0 !reset on 1 Jan for N-hemisphere, 1 July for S-hemisphere
   endif
        pheno_gdd = pheno_gdd + max(0.0, x-5.0)
   
   !pheno_ncd
   if ( (doy_now==304 .and. LAT>=0.0) .or. (doy_now==121 .and. LAT<0.0) ) then
        pheno_ncd = 0 !reset on 1 Nov for N-hemisphere, 1 May for S-hemisphere
   endif
   
   if ( x < 5.0 ) then
        pheno_ncd = pheno_ncd + 1
   end if
   
enddo

!prepare climatic factor 1
   tmp_air_10d_ave = sum( tmp_air_RunningRecord(1:10) ) / 10.0
   
!prepare climatic factor 2
   m = 0 ; n = 0 ; l = 7
   do j = 0, 4
      x = sum( tmp_air_RunningRecord(1+j*l    :l+j*l    ) )
      y = sum( tmp_air_RunningRecord(1+(j+1)*l:l+(j+1)*l) )
      if ( x > y ) then
         m = m + 1
      else
         n = n + 1
      endif
   enddo
   
   if (m>n) then
      flag_season = .false.  !temperature increasing
   else
      flag_season = .true.   !temperature decreasing
   endif
   
!initialization
   mass_assm    = 0.000
   mass_combust = 0.000
   
!__________________ Checker (Foliage -> Domance) __________________
flag(:) = .false.
DO p = 1, PFT_no
IF ( .not. pft_exist(p)   ) cycle
IF ( .not. phenology(p)   ) cycle
IF ( Phenology_type(p)==0 ) cycle
   
   x = tmp_air_10d_ave
   select case ( Phenology_type(p))
     
     case (1) !BoNS
       if (x < 7.0)                                          flag(p)=.true.
       
     case (2) !BoBS
       if ( tmp_soil<2.0 )                                   flag(p)=.true.
       
     case (3) !TeBS
       if ( (x<9.0) .or. (x<10.0+tmp_coldest_20yr_ave) )     flag(p)=.true.
       
     case (4) !water-controlling PFTs (Botta et al. 2000)
       if ( sum(stat_water_RunningRecord(p,1:10))/10.0<0.5 ) flag(p)=.true.
       
     case (5) !C3 grass
        flag(p)=.true.
        do k=1, 7
          if (lai_opt_grass_RunningRecord(1,k)>0.01)         flag(p)=.false.
        enddo
       
     case (6) !C4 grass
        flag(p)=.true.
        do k=1, 7
          if (lai_opt_grass_RunningRecord(2,k)>0.01)         flag(p)=.false.
        enddo
       
   end select
   if ( counter - pheno_clo(p) < 60 ) flag(p)=.false.
   
END DO

!__________________ Procedure (Foliage -> Dormance) __________________
DO p = 1, PFT_no
IF ( .not. flag(p) ) cycle
   if (Logging==1) write (*,*)  'Foliage phase ---> Domance phase', p, doy
   phenology(p) = .false.
   pheno_cls(p) = counter
END DO

!__________________ Gradual defoliation __________________
DO p = 1, PFT_no
day_until_bare = Shedding_duration - (counter-pheno_cls(p))
IF (day_until_bare < 1) cycle
   
   !for woody PFTs
   if ( (p.ne.C3g_no) .and. (p.ne.C4g_no) ) then
      do no=1, Max_no
      if (tree_exist(no) .and. pft(no)==p) then
          
          x                    = mass_leaf(no) / day_until_bare !leaf mass for shedding (g DM)
          mass_leaf     (no)   = mass_leaf(no) - x
          la            (no)   = mass_leaf(no) * SLA(P)
          mass_available(no)   = mass_available(no)   + x * RG_f_suck(p)
          
          pool_litter          = pool_litter          + x * (1.0-RG_f_suck(p))
          litter_flux_leaf(no) = litter_flux_leaf(no) + x * (1.0-RG_f_suck(p))
          
          !give minimum stock mass on the last leaf fall day
          if (day_until_bare==1 .and. mass_stock(no)<Stockmass_min_tree) then
             pool_litter    = pool_litter + mass_stock(no) - Stockmass_min_tree
             mass_stock(no) = Stockmass_min_tree
          end if
          
      end if
      end do
   
   !for Grass PFTs
   else
      
      if (p==C3g_no) then; gn=1
      else               ; gn=2
      endif
      
      x                  = gmass_leaf(gn) / day_until_bare !leaf mass for shedding (g DM)
      gmass_available(gn)= gmass_available(gn) + x * RG_f_suck(p)
      pool_litter        = pool_litter         + x * (1.0- RG_f_suck(p)) * area_cover(gn)
      !litter_flux_ag (gn)= litter_flux_ag (gn) + x * (1.0- RG_f_suck(p))
      gmass_leaf(gn)     = gmass_leaf(gn) - x
      lai_grass (gn)     = gmass_leaf(gn) * SLA(p)
      
      !give minimum stock mass
      if (day_until_bare==1 .and. gmass_stock(gn)<Stockmass_min_grass) then
         pool_litter     = pool_litter    + (gmass_stock(gn)-Stockmass_min_grass)*area_cover(gn)
         litter_flux_ag(gn) = litter_flux_ag(gn) + (gmass_stock(gn)-Stockmass_min_grass)
         gmass_stock   (gn) = Stockmass_min_grass
         
         if ( pool_litter < 0.0 ) then
            mass_assm   = mass_assm - pool_litter
            pool_litter = 0.0
         endif
         
      end if
   end if
   
END DO

!_____________ for carbon leaking checker 1
   a3 = pool_litter + mass_combust - mass_assm + &
     sum(mass_leaf)+sum(mass_root)+sum(mass_available)+sum(mass_stock)+ &               !Trees
     area_cover(1) * (gmass_leaf(1)+gmass_root(1)+gmass_available(1)+gmass_stock(1))+ & !C3 g
     area_cover(2) * (gmass_leaf(2)+gmass_root(2)+gmass_available(2)+gmass_stock(2))    !C4 g
   
   if ( abs(mass_total-a3)>20.0 .and. Logging==1 ) then
      write (*,*) 'Error @ Leaf_season1: leaking mass (g) ->', year, doy, mass_total-a3
   endif
   
!__________________ Checker (Dormance -> Foliage) __________________
flag(:) = .false.
DO p = 1, PFT_no
IF (.not. pft_exist(p)   ) cycle
IF (phenology(p)         ) cycle
IF (Phenology_type(p)==0 ) cycle
   
   !Checker (Dormance -> Foliage)
   select case ( Phenology_type(p) )
     
     case (1) !boreal deciduous needle-leaved-woods [by Picard et al 2005]
       x = 0.0
       do j = 1, doy
          x = x + max(0.0, tmp_air_RunningRecord(j)-4.1)
       end do
       
       if ( x >= 65.0 )                                        flag(p) = .true. 
       if ( LAT>=0.0 .and. (doy<100 .or. doy>190) )            flag(p) = .false.
       if ( LAT< 0.0 .and. (doy<212-LAT .or. doy>312-LAT) )    flag(p) = .false.
       
     case (2:3) !other temperature-controlling PFTs [Botta et al 2000 procedure]
       if ( pheno_gdd > -68.0 + 638.0 * exp(-0.01*pheno_ncd) ) flag(p) = .true. 
       if ( LAT>=0.0 .and. (doy< 30+LAT .or. doy>130+LAT) )    flag(p) = .false.
       if ( LAT< 0.0 .and. (doy<212-LAT .or. doy>312-LAT) )    flag(p) = .false.
       
     case (4) !water-controlling deciduous
       !if ( sum( stat_water_RunningRecord(p,51:55) ) > &
       !     sum( stat_water_RunningRecord(p,56:60) )   )           flag(p) = .true.
       !
       !j = 0
       !do k = 25, 50
       !   if ( stat_water_RunningRecord(p,k) > stat_water_RunningRecord(p,k+1) ) j=j+1
       !end do
       !if ( j<13 )                                                 flag(p) = .false.
       if ( sum(stat_water_RunningRecord(p,1:10)) / 10.0 > 0.5 )    flag(p) = .true.
       
     case (5) !C3grass
       flag(p)=.true.
       do k=1, 7
          if (lai_opt_grass_RunningRecord(1,k)<=0.01)   flag(p)=.false.
       enddo
       
       if ( LAT>=0.0 .and. (doy< 30+LAT .or. doy>130+LAT) )         flag(p) = .false.
       if ( LAT< 0.0 .and. (doy<212-LAT .or. doy>312-LAT) )         flag(p) = .false.
       
     case (6) !C4grass
       flag(p)=.true.
       do k=1, 7
          if (lai_opt_grass_RunningRecord(2,k)<=0.01)   flag(p)=.false.
       enddo
       
       if ( LAT>=0.0 .and. (doy< 30+LAT .or. doy>130+LAT) )         flag(p) = .false.
       if ( LAT< 0.0 .and. (doy<212-LAT .or. doy>312-LAT) )         flag(p) = .false.
       
   end select
   if ( counter - pheno_cls(p) < 60 ) flag(p)=.false.
   
END DO

!__________________ Procedure (Dormance -> Foliage) __________________
DO p = 1, PFT_no
IF (.not. flag(p)) cycle
   if (Logging==1) write (*,*) 'Domance phase ---> Foliage phase', p, doy
   phenology(p) = .true.
   pheno_clo(p) = counter
END DO

!__________________ Gradual release of stock energy __________________
DO p = 1, PFT_no
IF (.not. pft_exist(p)  ) cycle
IF (.not. phenology(p)  ) cycle
IF (Phenology_type(p)==0) cycle

IF (pheno_clo(p)+Day_length_release <= counter) cycle
   
   !For woody PFTs
   If ( (p.ne.C3g_no) .and. (p.ne.C4g_no) ) then
       do no=1, Max_no
       if (tree_exist(no) .and. pft(no)==p) then
          !x: stock mass for releasing in the day (g)
          x = mass_stock(no)/(Day_length_release+pheno_clo(p)-counter)
          
          !release process
          mass_available (no) = mass_available(no) + x / RG_stock_out
          mass_stock     (no) = mass_stock    (no) - x
          resp_root      (no) = resp_root     (no) + (x - x / RG_stock_out)
          mass_combust        = mass_combust       + (x - x / RG_stock_out)
          mort_regu1     (no) = mort_regu1     (no)- (x - x / RG_stock_out)
          npp            (p)  = npp(p)             - (x - x / RG_stock_out)
       endif
       enddo
   
   !For Grass species
   Else
      if (p==C3g_no) then; gn=1
      else               ; gn=2
      endif
      
      !x: stock mass consumed within a day (g/m2)
      x = gmass_stock(gn) / (Day_length_release+pheno_clo(p)-counter)
      
      !release process
      gmass_available(gn) = gmass_available(gn) + x / RG_stock_out
      gmass_stock    (gn) = gmass_stock    (gn) - x
      resp_grass_bg  (gn) = resp_grass_bg  (gn) + (x - x / RG_stock_out)
      mass_combust        = mass_combust        + (x - x / RG_stock_out)*area_cover(gn)
      npp (p)             = npp(p)              - (x - x / RG_stock_out)*area_cover(gn)
   Endif
   
END DO

!_____________ for carbon leaking checker 2
   a3 = pool_litter + mass_combust - mass_assm + &
     sum(mass_leaf)+sum(mass_root)+sum(mass_available)+sum(mass_stock)+ &               !Trees
     area_cover(1) * (gmass_leaf(1)+gmass_root(1)+gmass_available(1)+gmass_stock(1))+ & !C3 g
     area_cover(2) * (gmass_leaf(2)+gmass_root(2)+gmass_available(2)+gmass_stock(2))    !C4 g
   
   if ( abs(mass_total-a3)>20.0 .and. Logging==1 ) then
      write (*,*) 'Error @ Leaf_season2: leaking mass (g) ->', year, doy, mass_total-a3
   endif
   
!_____________ Total carbon emission by maintenance respiration
   c_emission = c_emission + mass_combust * C_in_drymass
   c_uptake   = c_uptake   + mass_assm    * C_in_drymass
   
END SUBROUTINE leaf_season



!**************************************************************************************************
! Maintenance respiration (daily computation)
!**************************************************************************************************
SUBROUTINE maintenance_resp (tmp_air, tmp_soil)

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   USE vegi_status_current2
   USE vegi_status_record
   USE grid_status_current1
   USE grid_status_record
   implicit none
   
!Set parameter
   real,parameter::Frac_organ_remove=0.01 !daily proportion biomass remove
                                       !when resource for maintenance respiration resource absent
!Define arguments
   real,intent(IN)::tmp_air  !air  temperature (Cecius)
   real,intent(IN)::tmp_soil !soil temperature (Cecius)
   
!Define local variables
   real qt                    !QT
   real tmp_sensibility_air   !temperature sensibility multiplier for foliage and stem
   real tmp_sensibility_soil  !temperature sensibility multiplier for root
   real resp_15C_air          !maintenance respiration mass of organ in air  at 15C (g)
   real resp_15C_soil         !maintenance respiration mass at organ in soil at 15C (g)
   real mass_required         !resource required for maintenance respiration (g)
   real mass_resp             !resource usage for mainatenance respiration (g)
   real f_sapwood             !sapwood_mass / stem_mass
   
   real mass_total            !total biomass before procedure --for checker-- (g DM/stand)
   real mass_combust          !biomass combust (g DM/day/stand)
   
   real mass_required_leaf  !carbon required for respiration for leaf               (gDM)
   real mass_required_trunc !carbon required for respiration for truc               (gDM)
   real mass_required_root  !carbon required for respiration for root               (gDM)
   real mass_required_ag    !carbon required for respiration for above ground grass (gDM)
   real mass_required_bg    !carbon required for respiration for below ground grass (gDM)
   
   integer no, i, p, gn    !loop counter
   real    a1, a2, a3      !for general usage
   real    x, y, z         !for general usage
   
   real,dimension(2)::area_coverage !coverage area for C3 and C4 grass (m2)4
   
!_____________ Area coverage for C3 and C4 grass (m2)
   IF (type_grass==3) then
      area_coverage(1) = 0.9 * (Max_loc**2)
      area_coverage(2) = 0.1 * (Max_loc**2)
   ELSE
      area_coverage(1) = 0.1 * (Max_loc**2)
      area_coverage(2) = 0.9 * (Max_loc**2)
   END IF
   
!_____________ Carbon-leak-checker 0
   mass_total = pool_litter + &                                                            !Litter
     sum(mass_leaf)+sum(mass_root)+sum(mass_available)+sum(mass_stock)+ &                  !Trees
     area_coverage(1) * (gmass_leaf(1)+gmass_root(1)+gmass_available(1)+gmass_stock(1))+ & !C3 g
     area_coverage(2) * (gmass_leaf(2)+gmass_root(2)+gmass_available(2)+gmass_stock(2))    !C4 g
   
!_____________ Set initial values and prepare related variables
!dry-mass to combust (g dm / stand)
   mass_combust = 0.000
   
!temperature sensibility, for foliage and sapwood
   !for aboveground organ
   qt                   = 2.0 * exp( -0.009 * (tmp_air-15.0)  )
   tmp_sensibility_air  = exp( (tmp_air  - 15.0) * log(qt) / 10.0 )
   !for belowground organ
   qt                   = 2.0 * exp( -0.009 * (tmp_soil-15.0) )
   tmp_sensibility_soil = exp( (tmp_soil - 15.0) * log(qt) / 10.0 )
   
!_____________ Woody PFTs
DO no=1, Max_no
   !set PFT number
   p = pft(no)
   
   If ( .not. tree_exist(no) ) cycle
   
   !Calculate daily resource required for maintenance respiration
   f_sapwood           = 1.0-(dbh_heartwood(no)**2)/( (dbh_sapwood(no)+dbh_heartwood(no))**2 )
   mass_required_leaf  = RM(p)* PN_f(p)* mass_leaf (no)           * tmp_sensibility_air
   mass_required_trunc = RM(p)* PN_s(p)* mass_trunk(no)* f_sapwood* tmp_sensibility_air
   mass_required_root  = RM(p)* PN_r(p)* mass_root (no)           * tmp_sensibility_soil
   mass_required       = mass_required_leaf + mass_required_trunc + mass_required_root
   
   !phase 1: use mass_available
   mass_resp         = min(mass_required, mass_available(no))
   
   mass_available(no)= mass_available(no) - mass_resp
   
   x                 = mass_resp / max(0.0001, mass_required) 
   resp_leaf (no)    = resp_leaf (no) + mass_required_leaf  * x
   resp_trunc(no)    = resp_trunc(no) + mass_required_trunc * x
   resp_root (no)    = resp_root (no) + mass_required_root  * x
   mort_regu1(no)    = mort_regu1(no) - mass_resp
   npp(p)            = npp(p)         - mass_resp
   mass_combust      = mass_combust   + mass_resp
   mass_required     = mass_required  - mass_resp
   
   !phase 2: use mass_stock
   if (mass_required > 0.001) then
      mass_resp      = min(mass_required, mass_stock(no)/ RG_stock_out)
      
      mass_stock(no) = mass_stock(no) - mass_resp * RG_stock_out
      
      resp_root(no)  = resp_root(no)  + mass_resp * RG_stock_out
      mort_regu1(no) = mort_regu1(no) - mass_resp * RG_stock_out
      npp(p)         = npp(p)         - mass_resp * RG_stock_out
      mass_combust   = mass_combust   + mass_resp * RG_stock_out
      mass_required  = mass_required  - mass_resp
   end if
   
   !phase 3: when resource absent, a portion of leaves drop
   if (mass_required > 0.001) then
      a1 = Frac_organ_remove * mass_leaf(no)   !leaf mass that will purged (gDM)
      a2 = Frac_organ_remove * mass_root(no)   !root mass that will purged (gDM)
      a3 = dbh_sapwood(no) * Frac_organ_remove !length of sapwood to heartwood (m)
      
      mass_leaf    (no) = mass_leaf    (no) - a1
      mass_root    (no) = mass_root    (no) - a2
      dbh_sapwood  (no) = dbh_sapwood  (no) - a3
      dbh_heartwood(no) = dbh_heartwood(no) + a3
      la           (no) = mass_leaf(no) * SLA(p)
      
      litter_flux_leaf(no) = litter_flux_leaf(no) + a1
      litter_flux_root(no) = litter_flux_leaf(no) + a2
      pool_litter          = pool_litter          + a1 + a2
   end if
      
   !record crown-bottom-layer stat_leaf
   x  = mass_leaf(no) / ( height(no)-bole(no) ) !leaf mass per crown disk(gDM/step)
   y  = x / FR_ratio(p)                         !required fine root for each crown disk(gDM/step)
   
   !a1: leaf maintenance cost (g/day/step)
   a1 = x * ( PN_f(p)*RM(p)*tmp_sensibility_air  + (TO_f(p)/365)*(RG_f(p)-RG_f_suck(p)) )
   
   !a2: root maintenance cost (g/day/step)
   a2 = y * ( PN_r(p)*RM(p)*tmp_sensibility_soil + (TO_r(p)/365)*RG_r(p)                )
   
   do i = 1, 10
   stat_leaf_crownbottom(no,i)     = stat_leaf_crownbottom(no,i)      - a1 - a2
   end do
   
   stat_leaf_crowntop(no)          = stat_leaf_crowntop(no)           - a1 - a2
   stat_leaf_crownbottom_daily(no) = stat_leaf_crownbottom_daily (no) - a1 - a2
   
   !benefit of producing new leaf mass (g / g Leaf)
   stat_leaf(no) = stat_leaf(no) - (a2+a3) / max(0.01,x)
   
End Do

!_____________ Carbon-leak-checker1
   x = pool_litter + mass_combust + &
   sum(mass_leaf)+sum(mass_root)+sum(mass_available)+sum(mass_stock)+ &
   area_coverage(1) * (gmass_leaf(1)+gmass_root(1)+gmass_available(1)+gmass_stock(1)) + &
   area_coverage(2) * (gmass_leaf(2)+gmass_root(2)+gmass_available(2)+gmass_stock(2))
   
   if ( abs(mass_total-x)>20.0 .and. Logging==1 ) then
      write (*,*) 'Error maintenance_respiration1: leaking mass (g) ->', abs(mass_total-x), doy
   end if
   
!_____________ Herbaceous PFTs
DO gn=1, 2 !( gn1->C3, gn2->C4 )
   !reset mass respiration 
   mass_resp  = 0.000
   
   !set pft number, p
   if (gn==1) then; p = C3g_no
   else           ; p = C4g_no
   endif
   
   !calculate daily mass_required for maintenance respiration (g/m2)
   mass_required_ag = RM(p) * PN_f(p) * tmp_sensibility_air  * gmass_leaf(gn)
   mass_required_bg = RM(p) * PN_r(p) * tmp_sensibility_soil * gmass_root(gn)
   mass_required    = mass_required_ag + mass_required_bg
   
   !Source 1: mass_available
   mass_resp          = min(mass_required, gmass_available(gn))
   
   gmass_available(gn)= gmass_available(gn) - mass_resp
   
   resp_grass_ag(gn)  = resp_grass_ag(gn) + mass_resp* (mass_required_ag/max(0.0001,mass_required))
   resp_grass_bg(gn)  = resp_grass_bg(gn) + mass_resp* (mass_required_bg/max(0.0001,mass_required))
   mass_combust       = mass_combust  + mass_resp * area_coverage(gn)
   npp(p)             = npp(p)        - mass_resp * area_coverage(gn)
   mass_required      = mass_required - mass_resp
   
   !Source 2: mass_stock
   if (mass_required > 0.001) then
      mass_resp         = min(mass_required, gmass_stock(gn)/RG_stock_out)
      
      gmass_stock  (gn) = gmass_stock  (gn) - mass_resp * RG_stock_out
      
      resp_grass_bg(gn) = resp_grass_bg(gn) + mass_resp * RG_stock_out
      mass_combust      = mass_combust      + mass_resp * RG_stock_out * area_coverage(gn)
      npp(p)            = npp(p)            - mass_resp * RG_stock_out * area_coverage(gn)
      mass_required     = mass_required     - mass_resp
   endif
   
   !Source 3: when resource absent
   if (mass_required > 0.001) then
    a1 = Frac_organ_remove * gmass_leaf(gn)
    a2 = Frac_organ_remove * gmass_root(gn)
    
    gmass_leaf(gn) = gmass_leaf(gn) - a1
    gmass_root(gn) = gmass_root(gn) - a2
    
    litter_flux_ag(gn) = litter_flux_ag(gn) + a1
    litter_flux_bg(gn) = litter_flux_bg(gn) + a2
    lai_grass     (gn) = gmass_leaf    (gn) * SLA(p)
    pool_litter        = pool_litter + (a1+a2) * area_coverage(gn)
   endif
   
END DO

!_____________ Carbon-leak-checker2
   x = pool_litter + mass_combust + &
   sum(mass_leaf)+sum(mass_root)+sum(mass_available)+sum(mass_stock)+ &
   area_coverage(1) * (gmass_leaf(1)+gmass_root(1)+gmass_available(1)+gmass_stock(1)) + &
   area_coverage(2) * (gmass_leaf(2)+gmass_root(2)+gmass_available(2)+gmass_stock(2))
   
   if ( abs(mass_total-x)>20.0 .and. Logging==1 ) then
       write (*,*) 'Error maintenance_respiration2: leaking mass (g) ->', abs(mass_total-x), doy
   end if
   
!_____________ Total carbon emission by maintenance respiration
   c_emission = c_emission + mass_combust * C_in_drymass
   
END SUBROUTINE maintenance_resp



!**************************************************************************************************
! Turnover (daily computation)
!**************************************************************************************************
SUBROUTINE turnover ()
!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   USE vegi_status_current2
   USE grid_status_current1
   USE grid_status_record
   implicit none
   
!Local variables
   real    t_rate      !daily turnover rate
   real    t_mass      !daily turnover mass
   real    mass_total  !for carbon leak chaker (g DM/stand)
   integer p           !for PFT number
   integer no, gn      !for loop counter
   real    x, y, z     !for general usage
   real    a1, a2      !for general usage
   
   real,dimension(2)::area_coverage !coverage area for C3 and C4 grass (m2)4
   
!_____________ Area coverage for C3 and C4 grass (m2)
   IF (type_grass==3) then
      area_coverage(1) = 0.9 * (Max_loc**2)
      area_coverage(2) = 0.1 * (Max_loc**2)
   ELSE
      area_coverage(1) = 0.1 * (Max_loc**2)
      area_coverage(2) = 0.9 * (Max_loc**2)
   END IF
   
!_____________ Carbon-leak-checker 0
   mass_total = pool_litter + &                                                          !Litter
   sum(mass_leaf)+sum(mass_root)+sum(mass_available)+sum(mass_stock)+ &                  !Trees
   area_coverage(1) * (gmass_leaf(1)+gmass_root(1)+gmass_available(1)+gmass_stock(1))+ & !C3 g
   area_coverage(2) * (gmass_leaf(2)+gmass_root(2)+gmass_available(2)+gmass_stock(2))    !C4 g
   
!_____________ Woody PFTs
DO no=1, Max_no 
if (tree_exist(no)) then
   !set pft number
   p = pft(no)
   
   !foliage
if ( Phenology_type(p)==0 .or. counter-pheno_clo(p)>365 ) then
   !evergreen
   t_rate = TO_f(p) / 365.000
else
   !summer or rain green
   x      = max( 1 , 365-(pheno_clo(p)-pheno_cls(p)) ) !number of growth day
   y      = max(0.0, TO_f(p) - 365/x)                  !corrected turnover rate
   t_rate = y / 365.000
end if
   
   t_mass             = mass_leaf(no) * t_rate !leaf mass to be drop (g DM)
   
   mass_leaf(no)      = mass_leaf(no)      - t_mass 
   mass_available(no) = mass_available(no) + t_mass * RG_f_suck(p)
   la(no)             = mass_leaf(no) * SLA(p)
   
   litter_flux_leaf(no) = litter_flux_leaf(no) + t_mass * (1.0 - RG_f_suck(p))
   pool_litter          = pool_litter          + t_mass * (1.0 - RG_f_suck(p))
   
   !root

if ( Phenology_type(p)==0 .or. counter-pheno_clo(p)>365 ) then
   !evergreen
   t_rate = TO_r(p) / 365.000
else
   !summer or rain green
   x      = max( 1 , 365-(pheno_clo(p)-pheno_cls(p)) ) !number of growth day
   y      = max(0.0, TO_r(p) - 365/x)                  !corrected turnover rate
   t_rate = y / 365.000
end if

   t_mass               = mass_root(no) * t_rate !root mass to be drop (g DM)
   mass_root(no)        = mass_root(no) - t_mass
   
   litter_flux_root(no) = litter_flux_root(no) + t_mass
   pool_litter          = pool_litter          + t_mass
   
   !sapwood
   if   (Life_type(p)==1) then
      !Tropical rain trees
      x = ALM5(p)       * (dbh_sapwood(no) + dbh_heartwood(no)) !new sapwood diameter   (m)
      y = (1.0-ALM5(p)) * (dbh_sapwood(no) + dbh_heartwood(no)) !new heartwood diameter (m)
      
      dbh_sapwood(no)   = x
      dbh_heartwood(no) = y
      
   elseif (Life_type(p)==2) then
      !Boreal deciduous trees
      x                 = dbh_sapwood(no) + dbh_heartwood(no) !DBH(m)
      dbh_sapwood(no)   = min(x, 0.0188)
      dbh_heartwood(no) = x - dbh_sapwood(no)
   else
      x                 = dbh_sapwood(no)
      y                 = dbh_heartwood(no)
      z                 = TO_s(pft(no)) / 365.0000
      t_rate            = sqrt( y*y + z*( x*x + 2*x*y ) ) - y
      dbh_sapwood(no)   = dbh_sapwood(no)   - t_rate
      dbh_heartwood(no) = dbh_heartwood(no) + t_rate
   endif
   
end if
END DO

!_____________ Carbon-leak-checker 1
   x = pool_litter + &
   sum(mass_leaf)+sum(mass_root)+sum(mass_available)+sum(mass_stock)+ &                  !Trees
   area_coverage(1) * (gmass_leaf(1)+gmass_root(1)+gmass_available(1)+gmass_stock(1))+ & !C3 g
   area_coverage(2) * (gmass_leaf(2)+gmass_root(2)+gmass_available(2)+gmass_stock(2))    !C4 g
   
   if ( abs(mass_total-x)>200.0 .and. Logging==1 ) then
      write (*,*) 'Error turnover1: leaking mass (g) ->', mass_total-x
   end if
   
!_____________ Herbaceous PFTs
DO gn=1, 2
   !set pft number, p
   p=C4g_no; if (gn==1) p=C3g_no
   
   !foliage turnover
   t_rate              = TO_f(p)/365.0000       !leaf turnover rate
   
   !foliage turnover
   if ( counter-pheno_clo(p)>365 ) then
     !evergreen
     t_rate = TO_f(p)/365.0000
   else
     !summer or rain green
     x      = max( 1 , 365-(pheno_clo(p)-pheno_cls(p)) ) !number of growth day
     y      = max(0.0, TO_f(p) - 365/x)                  !corrected turnover rate
     t_rate = y/365.000
   end if
   
   t_mass              = gmass_leaf(gn)*t_rate  !leaf mass to drop (g/m2)
   
   gmass_leaf     (gn) = gmass_leaf     (gn) - t_mass
   gmass_available(gn) = gmass_available(gn) + t_mass * RG_f_suck(p)
   lai_grass      (gn) = gmass_leaf     (gn) * SLA(p)
   
   litter_flux_ag (gn) = litter_flux_ag (gn)+ t_mass*(1.0-RG_f_suck(p))
   pool_litter         = pool_litter        + t_mass*(1.0-RG_f_suck(p))*area_coverage(gn)
   
   !root turnover
   t_rate              = TO_r(p)/365.0000       !leaf turnover rate
   t_mass              = gmass_root(gn)*t_rate  !root mass to drop (g/m2)
   
   gmass_root    (gn)  = gmass_root    (gn) - t_mass
   litter_flux_bg(gn)  = litter_flux_bg(gn) + t_mass
   pool_litter         = pool_litter        + t_mass*area_coverage(gn)
END DO
   
!_____________ Carbon-leak-checker 2
   x = pool_litter + &
   sum(mass_leaf)+sum(mass_root)+sum(mass_available)+sum(mass_stock)+ &                  !Trees
   area_coverage(1) * (gmass_leaf(1)+gmass_root(1)+gmass_available(1)+gmass_stock(1))+ & !C3 g
   area_coverage(2) * (gmass_leaf(2)+gmass_root(2)+gmass_available(2)+gmass_stock(2))    !C4 g
   
   if ( abs(mass_total-x)>200.0 .and. Logging==1 ) then
      write (*,*) 'Error turnover2: leaking mass (g) ->', mass_total-x
   end if
   
END SUBROUTINE turnover



!**************************************************************************************************
! growth woody PFTs (daily computation)
!**************************************************************************************************
SUBROUTINE growth_wood ()
!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   USE vegi_status_current2
   USE vegi_status_record
   USE grid_status_current1
   USE grid_status_record
   implicit none
   
!Local parameters for tropical rain forest from Huth & Ditzer (2000)
   ! bottom height of forest layer no 2,3,4,5 (m) 
   !(top    height of forest layer no 1,2,3,4 (m) )
   real,dimension(4),parameter::Layer_top = (/1.3, 15.0, 25.0, 36.0/)
   
   !maximum LAI for each layer (m2)
   real,parameter::LAI_max_cohort = 2.0
   
   !maximum LA that can increase within a day (fraction to crown area)
   real,parameter::LAgrow_max_day = 0.1
   
!_____________ Define local variables
!   real   ,dimension((int(0.99999+Max_loc/20.0))**2, 5)::cohort_lai    
!   logical,dimension((int(0.99999+Max_loc/20.0))**2, 5)::cohort_crowded
!   integer,dimension(Max_no)::id_location
!   integer,dimension(Max_no)::id_layer
   
   real   ,dimension(5)     ::layer_lai    !LAI for each crown layer (m2/m2)
   integer,dimension(Max_no)::layer_belong !crown layer number that each tree belongs
   
   integer p                      !for PFT number
   integer no, i, j               !for loop counter
   real    x                      !for temporal usage
   real    a1, a2, a3, a4, a5, a6 !for temporal usage
   real    mass_combust           !biomass combust (g DM/day/stand)
   real    mass_total             !total biomass before procedure --for checker-- (g DM/stand)
   
!_____________ Initialize
   mass_combust = 0.000
   mass_total   = sum(mass_leaf)+sum(mass_root)+sum(mass_available)+sum(mass_stock)+pool_litter
   
!_____________ Determine cohort structure
!   cohort_lai      (:,:) = 0.0     !(location,layer) crown area for each cohort (m2)
!   cohort_crowded  (:,:) = .false. !(location,layer) crowded flag for each cohort
!   id_location     (:)   = 0       !(tree_number)    location number that each tree belongs
!   id_layer        (:)   = 0       !(tree_number)    layer number that each tree belongs
!   
!   Do no=1, Max_no 
!   If ( tree_exist(no) ) then
!      
!      id_location(no) = 1+int(bole_x(no)/20) + 5*int(bole_y(no)/20) 
!      
!      x = height(no)*STEP+1.3 !x: tree height (m)
!      if     (x<Layer_top(1)) then ;id_layer(no) = 1
!      elseif (x<Layer_top(2)) then ;id_layer(no) = 2
!      elseif (x<Layer_top(3)) then ;id_layer(no) = 3
!      elseif (x<Layer_top(4)) then ;id_layer(no) = 4
!      else                         ;id_layer(no) = 5
!      endif
!      
!      cohort_lai(id_location(no),id_layer(no)) = &
!      cohort_lai(id_location(no),id_layer(no)) + la(no)*SLA(pft(no))
!      
!   End if
!   End do
!   
!   Do i=1, (int(0.99999+Max_loc/20.0))**2 !for each location
!   Do j=1, 5                              !for each layer
!      if ( cohort_lai(i,j)/400 > LAI_max_cohort ) cohort_crowded(i,j)=.true.
!   End do
!   End do
   
!_____________ Each individual of woody PFT procedure
DO no=1, Max_no 
IF ( .not. tree_exist(no)     ) cycle
IF ( .not. phenology(pft(no)) ) cycle
    
    !SET PFT NUMBER
    p = pft(no)
    
    !ROOT MASS SUPPLEMENT
    !a1: required root mass (g)
    a1 = max( 0.00000, mass_leaf(no)/FR_ratio(p) - mass_root(no) )
    !a2: maximum root mass increament allowded by available resource (g)
    a2 = mass_available(no) / RG_r(p)
    !a3 = actual increament of Root mass with considering resource_available
    a3 = min( a1, a2 )
    !root mass supplement precedure
    mass_root(no)      = mass_root(no)      +  a3                
    mass_available(no) = mass_available(no) -  a3 * RG_r(p)      
    
    resp_root (no)     = resp_root (no)     + (a3 * RG_r(p) - a3)
    mort_regu1(no)     = mort_regu1(no)     - (a3 * RG_r(p) - a3)
    mass_combust       = mass_combust       + (a3 * RG_r(p) - a3)
    npp(p)             = npp(p)             - (a3 * RG_r(p) - a3)
    
    !STOCK RESOURCE SUPPLEMENT
    if (counter > pheno_clo(p)+30) then !after more than 30 days from foliation
       !a1 = resource requirement for stock (g)
       a1 = max( 0.00000, mass_leaf(no) - mass_stock(no) )
       !a2 = maximum increment of mass_stock (g)
       a2 = mass_available(no) / RG_stock_in
       !a3:actual increment of mass_stock (g/m2)
       a3 = min( a1, a2 )
       
       !stock resource supplement precedure
       mass_stock    (no) = mass_stock    (no) +  a3                    
       mass_available(no) = mass_available(no) -  a3 * RG_stock_in      
       
       resp_root     (no) = resp_root      (no)+ (a3 * RG_stock_in - a3)
       mass_combust       = mass_combust       + (a3 * RG_stock_in - a3)
       npp(p)             = npp(p)             - (a3 * RG_stock_in - a3)
       mort_regu1(no)     = mort_regu1(no)     - (a3 * RG_stock_in - a3)
    end if
    
    !FOLIAGE MASS SUPPLEMENT
    !a1: deficit of foliage mass until fullfill existing crown size (g)
    if ( Life_type(p)==1 ) then
    !For TrBE
       a1 = crown_area(no)
    else
    !For other woody PFTs
       a1 = crown_area(no) + PI * crown_diameter(no) * real(height(no)-bole(no)) * STEP
    endif
    a1 = a1 * LA_max(p) / SLA(p)
    a1 = max(0.0, a1-mass_leaf(no) )
    
    !a2: deficit of foliage mass until fullfill existing Sapwood (g)
    if     ( Life_type(p)==1 ) then
    !For TrBE
       a2 = 100000.0 !This large value means that no constrain from this factor
    elseif ( Life_type(p)==2 ) then
    !For BoNS
      !a2 = 14.8 * ( (100*dbh_sapwood(no)+100*dbh_heartwood(no))**1.68 ) !Kajimoto et al (2006) 
       a2 = 330 + 50580 * ( (dbh_sapwood(no)+dbh_heartwood(no))**2 )      !Schulze et al (1995)
       a2 = max(0.0, a2-mass_leaf(no))
    else 
    !For other woody PFTs
       a2 = ALM1(p) * (1/SLA(p)) * (PI/4) * (dbh_sapwood(no)**2 + 2*dbh_sapwood(no)*dbh_heartwood(no))
       a2 = max(0.0, a2-mass_leaf(no) )
    endif
    
    !a3: maximum foliage mass with current resource available (g)
    a3 = mass_available(no) / RG_f(p)
    
    !a4: maximum foliage mass that can increase within a day (g)
    a4 = LAgrow_max_day * crown_area(no) / SLA(p)
    
    !a6: acutual increament of foliage mass (g)
    a6 = min(a1, a2, a3, a4)
    
    if ( Life_type(p)==1 ) then
    !For TrBE (Tropical broadleaved evergreeen trees)
      !if ( cohort_crowded(id_location(no),id_layer(no)) ) a6=0.0
       if ( stat_leaf_crownbottom_daily(no) < 0.0        ) a6=0.0
    elseif ( Life_type(p)==2 ) then
    !For BoNS (larch)
       if ( stat_leaf_crownbottom_daily(no) < 0.0        ) a6=0.0
    endif
    
    !reset daily leaf area stat on bottom of crown layer
    stat_leaf_crownbottom_daily(no) = 0.0
    
    !a6: actual increament (g)
    if ( a6 > 0.0) then
        mass_leaf(no)      = mass_leaf(no)       +  a6                
        mass_available(no) = mass_available(no)  -  a6 * RG_f(p)      
        la(no)             = mass_leaf(no) * SLA(p)
        
        resp_leaf(no)      = resp_leaf(no)       + (a6 * RG_f(p) - a6)
        mass_combust       = mass_combust        + (a6 * RG_f(p) - a6)
        npp(p)             = npp(p)              - (a6 * RG_f(p) - a6)
        mort_regu1(no)     = mort_regu1(no)      - (a6 * RG_f(p) - a6)
    end if
    
    !update mort_regu2 (annumal mean of leaf area)
    mort_regu2(no) = mort_regu2(no) + la(no)/365
    
END DO

!_____________ carbon leak checker
   !a1 = sum(mass_leaf)+sum(mass_root)+sum(mass_available)+sum(mass_stock)+pool_litter+mass_combust
   !a2 = abs(mass_total - a1)
   !if ( a2>100.0 .and. Logging==1 ) then
   !   write (*,*) 'Error @ growth_wood: leaking mass (g) ->', a2
   !end if
   
!_____________ carbon emission
   c_emission = c_emission + mass_combust * C_in_drymass
   
End subroutine growth_wood



!**************************************************************************************************
! growth_grass (daily computation)
!**************************************************************************************************
SUBROUTINE growth_grass ()
!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   USE vegi_status_current2
   USE vegi_status_record
   USE grid_status_current1
   USE grid_status_record
   implicit none
   
!Local parameter
   real,parameter::Grass_seeds = 0.1 !grass seeds biomass that always present (g/m2)
                                     !This value should be very small
   
!Local variables
   real               lai_opt      !optimum LAI of grass layer (m2/m2)
   real               mass_combust !biomass combust (g dm/day/stand)
   real               mass_total   !total biomass and litter before procedure (DM g stand-1)
   integer            p            !PFT number
   integer            gn           !for loop counter
   real               a1, a2, a3   !for temporal usage
   real,dimension(2)::area_cover   !coverage area for each grass PFT (m2)
   
!_____________ Initialize local variables
   mass_combust = 0.000
   
   if (type_grass==3) then
      area_cover(1) = 0.9 * Max_loc * Max_loc !Area coveraged by C3 grass (m2)
      area_cover(2) = 0.1 * Max_loc * Max_loc !Area coveraged by C4 grass (m2)
   else
      area_cover(1) = 0.1 * Max_loc * Max_loc !Area coveraged by C3 grass (m2)
      area_cover(2) = 0.2 * Max_loc * Max_loc !Area coveraged by C4 grass (m2)
   endif
   
!_____________ carbon leak checker (before procedure)
   a1 = gmass_leaf(1)+gmass_root(1)+gmass_available(1)+gmass_stock(1) !C3 grass biomass (DM g m-2)
   a2 = gmass_leaf(2)+gmass_root(2)+gmass_available(2)+gmass_stock(2) !C4 grass biomass (DM g m-2)
   mass_total = a1*area_cover(1) + a2*area_cover(2) + pool_litter
   
!_____________ each grass type procedure
DO gn = 1, 2
    
    !set pft number: p
    if (gn==1) p=C3g_no
    if (gn==2) p=C4g_no
    
IF ( phenology(p) ) then
    
    !set lai_opt, running mean of optimum leaf area index
    lai_opt = sum(lai_opt_grass_RunningRecord(gn,1:7)) / 7.0
    
    !excess foliage senescence procedure (optional)
    ! if (lai_grass(gn) > lai_opt) then
    !    !a1: excess gmass_leaf (g drymatter/m2)
    !    a1             = (lai_grass(gn)-lai_opt) / SLA(p)
    !    !a2: gmass_leaf that senescence (g drymatter/m2)
    !    a2             = a1 * 0.020
    !    gmass_leaf(gn) = gmass_leaf(gn) - a2
    !    pool_litter    = pool_litter    + a2 * area_cover(gn)
    !    lai_grass(gn)  = gmass_leaf(gn) * SLA(p)
    ! end if
    
    !root mass supplement
       !a1: required root mass (g dm / m2)
        a1 = max(0.0, gmass_leaf(gn)/FR_ratio(p) - gmass_root(gn))
       !a2: maximum root mass increament (g dm / m2)
        a2 = gmass_available(gn) / RG_r(p)
       !a3: actual increamet of root mass (g dm / m2)
        a3 = min(a1, a2)
       !root mass supplement procedure
        gmass_available(gn) = gmass_available(gn) - a3 * RG_r(p)
        gmass_root     (gn) = gmass_root     (gn) + a3          
        
        resp_grass_bg  (gn) = resp_grass_bg  (gn) + a3 * (RG_r(p)-1.0)
        mass_combust        = mass_combust        + a3 * (RG_r(p)-1.0) * area_cover(gn)
        npp            (p)  = npp            (p)  - a3 * (RG_r(p)-1.0) * area_cover(gn)
       
    !stock resource supplement
    if ( counter > pheno_clo(p)+30 ) then !after more than 30 days from foliation
       !a1:resource requirement for stock (g/m2)
        a1 = max( 0.0, gmass_leaf(gn) - gmass_stock(gn) )
       !a2:maximum increment of mass_stock with resource available (g/m2)
        a2 = gmass_available(gn) / RG_stock_in
       !a3:actual increment of mass_stock (g/m2)
        a3 = min( a1, a2 )
       !stock mass increment precedure
        gmass_available(gn) = gmass_available(gn) - a3 * RG_stock_in 
        gmass_stock    (gn) = gmass_stock    (gn) + a3               
        
        resp_grass_bg  (gn) = resp_grass_bg  (gn) + a3 * (RG_stock_in-1.0)
        mass_combust        = mass_combust        + a3 * (RG_stock_in-1.0) * area_cover(gn)
        npp            (p)  = npp            (p)  - a3 * (RG_stock_in-1.0) * area_cover(gn)
    endif
    
    !foliage growth
       !a1: maximum foliage mass requirement (g/m2)
        a1 = (lai_opt - lai_grass(gn)) / SLA(p)
        a1 = max(a1, 0.0)
       !a2: maximum increament of folige mass that available resource permits (g/m2)
        a2 = gmass_available(gn) / RG_f(p)
       !a3: actual increament of foliage mass (g/m2)
        a3 = min(a1, a2)
       
       !foliage mass increament procedure
        gmass_available(gn) = gmass_available(gn) - a3 * RG_f(p)
        gmass_leaf     (gn) = gmass_leaf     (gn) + a3          
        lai_grass      (gn) = gmass_leaf     (gn) * SLA(p)
        
        resp_grass_ag  (gn) = resp_grass_ag  (gn) + a3 * (RG_f(p)-1.0)                 
        mass_combust        = mass_combust        + a3 * (RG_f(p)-1.0) * area_cover(gn)
        npp            (p)  = npp            (p)  - a3 * (RG_f(p)-1.0) * area_cover(gn)
        
    !reproduction: excess resource will be added to litter
    if ( counter > pheno_clo(p)+30    ) then !after more than 30 days from foliation
    if ( gmass_stock(gn) > 100.0 ) then !minimum stock resource for reproduction (g dm /m2)
       litter_flux_ag(gn)  = litter_flux_ag(gn) + gmass_available(gn)
       pool_litter         = pool_litter        + gmass_available(gn)*area_cover(gn)
       gmass_available(gn) = 0.000000
    endif
    endif
    
END IF
END DO
   
!_____________ Give minimum resource as seeds
DO gn = 1, 2
   if (gmass_leaf(gn)+gmass_root(gn)+gmass_available(gn)+gmass_stock(gn) < Grass_seeds) then
      gmass_stock(gn) = Grass_seeds
   end if
END DO
   
!_____________ carbon emission (C g / month / stand)
   c_emission = c_emission + mass_combust * C_in_drymass
   
!_____________ carbon leak checker (after procedure)
   a1 = gmass_leaf(1)+gmass_root(1)+gmass_available(1)+gmass_stock(1) !C3 grass biomass (DM g m-2)
   a2 = gmass_leaf(2)+gmass_root(2)+gmass_available(2)+gmass_stock(2) !C4 grass biomass (DM g m-2)
   
   a3 = a1 * area_cover(1) + a2 * area_cover(2) + pool_litter + mass_combust
   a3 = abs(a3-mass_total)
   
   if ( a3>5.0 .and. Logging==1 ) then
      write (*,*) 'Error @ growth grass: leaking mass (g/m2) ->', a3
   end if
   
End subroutine growth_grass



!**************************************************************************************************
! Crown depth adjustment
!**************************************************************************************************
SUBROUTINE crown_adjust ()
!_____________ Set variables
!Namespace
   USE data_structure
   USE vegi_status_current1
   USE vegi_status_record
   USE grid_status_current1
   implicit none
   
!Parameter (minimum crown depth in STEP)
   integer,parameter::Crown_depth_min = 10
   
!Local variables
   real    hgt          !height of tree (m)
   real    bol          !height of bole (m)
   real    mass_total   !mass before procedure --for checker-- (g)
   integer count        !number of crown layers to purge
   integer p            !PFT number
   integer no,i         !for general usage
   real    a1,a2,x      !for general usage
   
!_____________ Save mass_total for carbon-leak-checker
   mass_total = sum(mass_leaf) + pool_litter
   
!_____________ Determine number of crown disks that will be purged
DO no=1, Max_no 
if ( .not. tree_exist(no) )                   cycle
if ( height(no)-bole(no) <= Crown_depth_min ) cycle
   
   p     = pft(no)               !PFT number
   hgt   = height(no)*STEP + 1.3 !tree height (m)
   bol   = bole  (no)*STEP + 1.3 !bole height (m)
   count = 0                     !number of crown disk that will be purged
   Select case ( Life_type(p) )
   Case (1)     !Trees of tropical rain forest
      !if ( hgt > 34.0 ) then
      !   x = 0.18
      !else
      !   x = 0.0002 * hgt * hgt - 0.0182 * hgt + 0.6
      !endif
      !x = x * hgt                    !new crown depth (m)
      
      x = ALM6(p) * hgt
      
      i = int( height(no) - x/STEP ) !new bole height (STEP)
      count = max(0, i - bole(no))
      
   Case (2)     !Boreal deciduous trees
      x = max( 0.0, height(no)*Step+1.3 - 10.0) !minimum bole height (m)
      i = int( (x-1.3) / STEP )                 !minimum bole height (STEP)
      
      count = max(count, i-bole(no) )
      
   Case default !default standard
      do i = 1, min(10, height(no)-bole(no)-1)
         if ( sum(stat_leaf_crownbottom(no,1:i))/i < stat_leaf_crowntop(no)*ALM4(p) ) count = i
      end do
   
   End select
   count = min(count, height(no)-bole(no)-Crown_depth_min)
   
    !when maximum_crown_depth was assumed
    ! max_depth = 30
    ! if ( height(no)-bole(no)-max_depth > 0 ) then
    !    count = max(count, height(no)-bole(no)-max_depth )
    ! end if
    
    !crown adjust procedures
    if (count > 0) then
    !  la_step              = la(no) / real( height(no)-bole(no) )
    !  la(no)               = la(no)      - la_step * count
    !  mass_leaf(no)        = mass_leaf(no)        - la_step * count / SLA(pft(no))
    !  litter_flux_leaf(no) = litter_flux_leaf(no) + la_step * count / SLA(pft(no))
    !  pool_litter          = pool_litter          + la_step * count / SLA(pft(no))
       bole(no)    = bole(no)    + count
    endif
   
END DO
   
!_____________ Reset bole-height-adjust control variables
   stat_leaf_crownbottom(:,:) = 0.0
   stat_leaf_crowntop(:)      = 0.0
   
!_____________ Carbon leak checker
   a1 = sum(mass_leaf) + pool_litter !total carbon
   a2 = abs(a1 - mass_total)      !difference in total carbon
   if ( a2>5.0 .and. Logging==1 ) then
        write (*,*) 'Error @ crown_adjust: leaking mass (g) ->', a2
   end if
   
END SUBROUTINE crown_adjust



!**************************************************************************************************
! Monthly growth and reproduction of woody PFT (each individual_tree procedure)
!**************************************************************************************************
SUBROUTINE growth_trunc ()

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   USE vegi_status_current2
   USE vegi_status_record
   USE grid_status_current1
   USE grid_status_record
   implicit none
   
!Local parameter
   !fraction of available resource allocates to reproduction 
   real,parameter::Frac_mass_reproduction = 0.10
   
   !delay of stem growth and reproduction process after foliation (day)
   integer,parameter::Delay_from_foliation = 21
   
   !Threshold biomass that initiate reproduction (DM g)
   real,parameter::Thres_mass_reproduct = 10000.0
   
!Local variables
   real    diameter_new   !new diameter (m)
   real    mass_trunk_tmp !stem biomass for temporal usage (dm g)
   integer height_new     !new tree height (STEP)
   real    dn, md, up     !for convergence loop
   real    mass_combust   !biomass combust (g DM/day/stand)
   real    mass_total     !total biomass before procedure --for checker-- (g DM/stand)
   real    x, y           !for general usage
   integer no, p, count   !
   
!_____________ For carbon leak checker
   mass_combust = 0.000
   mass_total   = sum(mass_trunk) + sum(mass_available) + pool_litter + mass_combust
   
!_____________ Growth process for each tree
DO no=1, Max_no 

p = pft(no)

IF ( tree_exist(no)                              ) then !when tree exist
IF ( phenology(p)                                ) then !when on foliation phase
IF ( counter > pheno_clo(p)+Delay_from_foliation ) then !after specific day from foliation
IF ( mass_available(no) > 0.0                    ) then !when mass available exist
   
   !Reproduction
   x = mass_leaf(no)+mass_trunk(no)+mass_root(no)+mass_stock(no)+mass_available(no)
   If (x > Thres_mass_reproduct) then
      pool_litter          = pool_litter          + mass_available(no)*Frac_mass_reproduction
      litter_flux_leaf(no) = litter_flux_leaf(no) + mass_available(no)*Frac_mass_reproduction
      mass_available  (no) = mass_available  (no) * (1.0-Frac_mass_reproduction )
   Endif
   
   !Adjust mass available
   If (Life_type(p)==1) then
      !For tropical rain trees
      x = ( (dbh_heartwood(no)+dbh_sapwood(no)) / DBH_limit(p) )**2
      x = min(1.0, x)      !diminishing factor due to size limitation
      y = mass_available(no) / max(0.01, gpp_month_ind(no))
      y = min(1.0, y)      !diminishing factor due to NPP/GPP balance
      
      mass_combust      = mass_combust        + mass_available(no) * x * y
      resp_leaf     (no)= resp_leaf       (no)+ mass_available(no) * x * y
      npp            (p)= npp              (p)- mass_available(no) * x * y
      mort_regu1    (no)= mort_regu1      (no)- mass_available(no) * x * y !Annual NPP (gDM)
      mass_available(no)= mass_available  (no)- mass_available(no) * x * y
      
   ELSE If (Life_type(p)==2) then
      !For boreal deciduous trees
      x = ( (dbh_heartwood(no)+dbh_sapwood(no)) / DBH_limit(p) )**2
      x = min(1.0, x)      !diminishing factor due to size limitation
      
      mass_combust       = mass_combust       + mass_available(no) * x
      resp_leaf     (no) = resp_leaf     (no) + mass_available(no) * x
      npp            (p) = npp            (p) - mass_available(no) * x
      mort_regu1    (no) = mort_regu1    (no) - mass_available(no) * x !Annual NPP (gDM)
      mass_available(no) = mass_available(no) - mass_available(no) * x
   End if
   
   !Allocate all remaining mass_available to sapwood production
   x                  = mass_available(no) / RG_s(p)
   mass_trunk(no)     = mass_trunk(no) +  x
   
   resp_trunc    (no) = resp_trunc(no) + (mass_available(no) - x)
   npp            (p) = npp        (p) - (mass_available(no) - x)
   mort_regu1    (no) = mort_regu1(no) - (mass_available(no) - x)
   mass_combust       = mass_combust   + (mass_available(no) - x)
   mass_available(no) = 0.0
   
   !determine DBH increament
   up = 0.1000000; dn = 0.0000000 !lengh to examine convergence
   count = 0
   Do
      count = count + 1
      !current sapwood diameter increament (m)
      md             = (up+dn) / 2.0
      !current diameter (m)
      diameter_new   = dbh_heartwood(no) + dbh_sapwood(no) + md
      !current height (STEP)
      height_new     = max(height(no), min(height_limit(no), h(diameter_new, p) ))
      !current trunk mass (g)
      mass_trunk_tmp = stem_weight(diameter_new, height_new, p)
      !x: difference in stem mass (g)
      x = mass_trunk_tmp - mass_trunk(no)
      !examine convergence
      if    (x < 0.0000000) then ; dn = md
      else                       ; up = md
      end if                               
      if (up-dn < 0.0001) exit !error should be less than 1/10 (mm/month)
      if (count > 1000)   exit !avoid infinite loop
   End do
   
   !adjust trunc diameter and height
   height(no)      = height_new
   dbh_sapwood(no) = dbh_sapwood(no) + md 
   mort_regu4(no)  = mort_regu4(no)  + md !annual increament of DBH
   
   !adjust crown diameter ( x=crown_area(m2) )
   if     (Life_type(p)==1 .and. diameter_new>0.2) then
      !tropical evergreen trees (large)
      x = ( 25*diameter_new     )**2 * PI / 4.0
   elseif (Life_type(p)==1              )          then
      !tropical evergreen trees (small)
      x = ( (50-125*diameter_new)*diameter_new )**2 * PI / 4.0
   elseif (Life_type(p)==2              )          then
      !boreal deciduous needle leaf trees
      x = 80*diameter_new
   else
      !other trees
      x = ALM2(p) * (diameter_new**1.6)
   endif
   
   x = min( x, PI*CD_max(p)*CD_max(p)/4.0           )
   x = min( x, PI*radius_limit(no)*radius_limit(no) )
   x = max( x, 0.001                                )
   
   crown_area(no)     = x
   crown_diameter(no) = 2 * sqrt(x/PI)
   
END IF
END IF
END IF
END IF
END DO

!_____________ Carbon leak checker
!x = sum(mass_trunk) + sum(mass_available) + pool_litter + mass_combust
!y = abs(mass_total - x)
!if ( y>100.0 .and. Logging==1 ) then
!   write (*,*) 'Error @ growth_stem: leaking mass (DM g) ->', y
!end if

!_____________ Carbon emission
c_emission = c_emission + mass_combust * C_in_drymass

END SUBROUTINE growth_trunc



!**************************************************************************************************
! Calculation of photosynthesis parameters (for each PFT)
!**************************************************************************************************
SUBROUTINE decomposition (W_sat)
   
   USE data_structure
   USE grid_status_current1
   USE grid_status_record
   implicit none
   
!_____________ Define arguments
   real,intent(IN)   ::W_sat !saturate point   (m3/m3, 0.0 -> 1.0)

!_____________ Define local variable
   real effect_tmp      !temperature coefficient for decomposition
   real effect_mois     !moisture    coefficient for decomposition
   real d_rate_litter   !decomposition rate of litter   (month-1)
   real d_rate_som_int  !decomposition rate of som_int  (month-1)
   real d_rate_som_slow !decomposition rate of som_slow (month-1)
   real mass_decomp     !decomposed organic matter (g dm month-1 stand-1)
   real aet             !1yr actual evapotranspiration (mm year-1)
   
   real c_before        !total carbon before procedure   -for checker- (g C/stand)
   real c_after         !total carbon before procedure   -for checker- (g C/stand)
   real x               !for general usage
   
!_____________ Checker
   c_before = (pool_litter+pool_som_int+pool_som_slow)*C_in_drymass + c_emission
   
!_____________ Calculatet decomposition coefficients
  !effect_tmp     = exp( 0.230259 * (tmp_soil_month_ave-20.0) ) !Q10 method
   effect_tmp     = exp( 308.56 * ( 1.0/66.02 - 1.0/( max(-45.0, tmp_soil_month_ave)+46.02) ) )
   effect_mois    = 0.25 + 0.75 * ( (sum(pool_w(1:5))/5.0) / W_sat / Depth)
   
!_____________ Calculate decomposition rates
   aet = sum(hyd_ic_RunningRecord(:))+sum(hyd_ev_RunningRecord(:))+sum(hyd_tr_RunningRecord(:))
   
!   d_rate_litter   = max(0.0 , 0.000597*aet-0.0131369 )   !Meentemeyer(1978)
   d_rate_litter   = 10**(0.0014175*aet-1.4553)            !Foley(1995)
   d_rate_litter   = d_rate_litter / 12.0
   d_rate_som_int  = (effect_tmp * effect_mois) * (TO_fast  / 12.0)
   d_rate_som_slow = (effect_tmp * effect_mois) * (TO_slow / 12.0)
   
   d_rate_litter   = min(1.0, d_rate_litter  )
   d_rate_som_int  = min(1.0, d_rate_som_int )
   d_rate_som_slow = min(1.0, d_rate_som_slow)

!_____________ Decomposition procedure1, litter
   mass_decomp     = pool_litter * d_rate_litter
   !write (*,*) '1 ->', pool_litter, d_rate_litter, mass_decomp
   pool_litter     = pool_litter   - mass_decomp
   pool_som_int    = pool_som_int  + mass_decomp * (1.00-F_air) * F_inter
   pool_som_slow   = pool_som_slow + mass_decomp * (1.00-F_air) * (1.00 - F_inter)
   c_emission      = c_emission    + mass_decomp * F_air * C_in_drymass
   
!_____________ Decomposition procedure2, s.o.m. with intermediated composition rate
   mass_decomp     = pool_som_int * d_rate_som_int
   pool_som_int    = pool_som_int - mass_decomp
   c_emission      = c_emission   + mass_decomp * C_in_drymass
   
!_____________ Decomposition procedure3, s.o.m. with slow composition rate
   mass_decomp     = pool_som_slow * d_rate_som_slow
   pool_som_slow   = pool_som_slow - mass_decomp
   c_emission      = c_emission    + mass_decomp * C_in_drymass
   
!_____________ Carbon leak checker
   c_after = (pool_litter+pool_som_int+pool_som_slow)*C_in_drymass + c_emission
   x = c_before - c_after
   
   if ( abs(x)>10.0 .and. Logging==1 ) then
      write (*,*) 'Error @ decomposiotion: leaking mass (g) ->', x
   end if
   
END SUBROUTINE decomposition